==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebCancelableBrowserEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableBrowserEventArgsDetailDescriptionMetadata, _super);
    function WebCancelableBrowserEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
        a.item("__isPlainObject", "Boolean");
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.d = function (a) {
        WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
        a.z("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
}(Base));
export { WebCancelableBrowserEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebCancelableBrowserEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableBrowserEventArgsDetailDescriptionMetadata, _super);
    function WebCancelableBrowserEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
        a.item("__isPlainObject", "Boolean");
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.d = function (a) {
        WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
        a.ab("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
}(Base));
export { WebCancelableBrowserEventArgsDetailDescriptionMetadata };
